==> deepin-system-monitor_1.0.0-1.tar.xz: deepin-system-monitor-1.4.8/translations/deepin-system-monitor_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Processo</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Início</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation>Leitura do disco</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Gravação do disco</translation>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não habilitado</translation>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Leitura do disco</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Gravação do Disco</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Forçar para encerrar aplicação</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema Escuro</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Finalizar aplicação</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Finalizar esta aplicação pode causar a perda de dados.
Tem certeza que deseja continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation>Modo compacto</translation>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não habilitado</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Sem resposta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Finalizar processo</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Finalizar este processo pode causar a perda de dados.
Tem certeza que deseja continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspender processo</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Resumir processo</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Visualizar a localização do processo</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 aplicações e %3 processos em execução</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escrever disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Ler disco</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Monitor do Sistema é um intuitivo e poderoso monitor. Pode monitorar e analisar os processos da CPU, memória, rede, disco e outros status.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Monitor do Sistema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Monitor do Sistema</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Desktop Environment - Process initiation service</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Desktop Environment - Desktop</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Desktop Environment - Polkit proxy</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Desktop Environment - Lançador</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Desktop Environment - Dock</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Desktop Environment - Tela</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Desktop Environment - Daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Desktop Environment - Session daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Desktop Environment - Session initialization process</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Gerenciando de Arquivos daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Desktop Environment - Serviço de bloqueio de tela</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Gerenciador de Janelas</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Alternador do Gerenciador de Janelas</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Deepin notificações</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Agente do Deepin Cloud Print</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Deepin serviço de menu</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Deepin Store daemon</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Correspondência de janelas daemon</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Serviço DBus de correspondência de janelas daemon</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Daemon do sistema de arquivos virtual do modo de usuário</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Servidor de fusíveis do sistema de arquivo virtual do modo usuário daemon </translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Processo de ajuda do cliente Deepin Store</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Gerenciador de rede</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Serviço PolicyKit DBu</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Serviço de compartilhamento de arquivos daemon</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Serviço X</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Método de entrada Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Método de entrada Fcitx daemon DBus</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Método de entrada Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Cliente local ShadowSocks </translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Serviço de som</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Impressão daemon</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Gerenciador de brilho da tela</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Gerenciador de serviços do sistema</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>System service manager -  Gerenciamento de dispositivos daemon</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Daemon de disco</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Daemon de contas</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Daemon DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Eventos do mouse daemon</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Serviço DConf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Gnome keyring daemon</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Bluetooth daemon</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Daemon de energia</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Gerenciador de modem</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Serviço de bandeja de impressão do sistema</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Chrome browser sandbox</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Dispositivo Synaptics touchpad</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não habilitado</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation>Método de entrada Sogou</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Clique na aplicação que deseja finalizar</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Meus processos</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Todos os processos</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Bandeja</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_1.4.3.orig.tar.xz: deepin-system-monitor-1.4.3/translations/deepin-system-monitor_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Processo</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Início</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Total</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Forçar para encerrar aplicação</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema dark</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Finalizar aplicação</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Finalizar esta aplicação pode causar a perda de dados.
Tem certeza que deseja continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não habilitado</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Sem resposta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Finalizar processo</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Finalizar este processo pode causar a perda de dados.
Tem certeza que deseja continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspender processo</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Resumir processo</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Visualizar a localização do processo</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 aplicações e %3 processos em execução</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escrever disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Ler disco</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Deepin System Monitor é um intuitivo e poderoso monitor de sistema. Pode monitorar os processos da CPU, memória, rede, disco e outros status.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin System Monitor</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin System Monitor</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Desktop Environment - Process initiation service</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Desktop Environment - Desktop</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Desktop Environment - Polkit proxy</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Desktop Environment - Lançador</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Desktop Environment - Dock</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Desktop Environment - Tela</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Desktop Environment - Daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Desktop Environment - Session daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Desktop Environment - Session initialization process</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Deepin Gerenciando de Arquivos daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Desktop Environment - Serviço de bloqueio de tela</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Deepin Gerenciador de Janelas</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Alternador do Deepin Gerenciador de Janelas</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Deepin notificações</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Agente do Deepin Cloud Print</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Deepin serviço de menu</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Deepin Store daemon</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Correspondência de janelas daemon</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Serviço DBus de correspondência de janelas daemon</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Daemon do sistema de arquivos virtual do modo de usuário</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Servidor de fusíveis do sistema de arquivo virtual do modo usuário daemon </translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Processo de ajuda do cliente Deepin Store</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Gerenciador de rede</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Serviço PolicyKit DBu</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Serviço de compartilhamento de arquivos daemon</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Serviço X</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Método de entrada Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Método de entrada Fcitx daemon DBus</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Método de entrada Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Cliente local ShadowSocks </translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Serviço de som</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Impressão daemon</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Gerenciador de brilho da tela</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Gerenciador de serviços do sistema</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>System service manager -  Gerenciamento de dispositivos daemon</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Daemon de disco</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Daemon de contas</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Daemon DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Eventos do mouse daemon</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Serviço DConf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Gnome keyring daemon</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Bluetooth daemon</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Daemon de energia</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Gerenciador de modem</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Serviço de bandeja de impressão do sistema</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Chrome browser sandbox</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Dispositivo Synaptics touchpad</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Não habilitado</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Clique na aplicação que deseja finalizar</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Meus processos</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Todos os processos</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
</TS>
